@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     wangchunlin<wangchunlin@uniontech.com>
- *
- * Maintainer: wangchunlin<wangchunlin@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef HYPERLINKLABEL_H
 #define HYPERLINKLABEL_H
 
@@ -25,6 +9,8 @@
 #include <QFontMetrics>
 #include <QRegion>
 
+namespace GrandSearch {
+
 class HyperlinkLabel : public QLabel
 {
     Q_OBJECT
@@ -50,4 +36,6 @@ private:
     QRegion m_hyperlinkRegion;    // 超链接的绘制区域
 };
 
+}
+
 #endif // HYPERLINKLABEL_H
